{
  pkgs',
  system,
  self,
  ...
}: let
  scriptUpdateProject = pkgs'.callPackage ./update-project.nix {inherit pkgs' self system;};
  scriptUpdateChangelog = pkgs'.callPackage ./update-changelog.nix {inherit pkgs' self system;};
  scriptInitProject = pkgs'.callPackage ./init-project.nix {inherit pkgs' self system;};
  scriptBuildStylesheets = pkgs'.callPackage ./build-stylesheets.nix {inherit pkgs' self system;};
  scriptDeploy = pkgs'.callPackage ./deploy.nix {inherit pkgs' self system;};
  scriptUpdateWebTest = pkgs'.callPackage ./update-web-test.nix {inherit pkgs' self system;};
  scriptRunTests = pkgs'.callPackage ./run-tests.nix {inherit pkgs' self system;};
  scriptRunWebTests = pkgs'.callPackage ./run-web-tests.nix {inherit pkgs' self system;};
  scriptCreateNewComponentclass = pkgs'.callPackage ./create-new-class.nix {inherit pkgs' self system;};
  scriptCreateDocumentationFiles = pkgs'.callPackage ./create-documentation-files.nix {inherit pkgs' self system;};
  scriptCreateIssue = pkgs'.callPackage ./create-issue.nix {inherit pkgs' self system;};
  scriptStartServer = pkgs'.callPackage ./start-server.nix {inherit pkgs' self system;};

  taskfile = pkgs'.writeTextFile {
    name = "taskfile.yml";
    text = ''
      version: '3'

      tasks:
          default:
            cmds:
              - task --list
            silent: true

          git-commit:
            desc: Commit changes.
            aliases:
              - f
            cmds:
              - ${scriptUpdateProject}/bin/update-project
              - cd "{{.USER_WORKING_DIR}}" && cd $(${pkgs'.git}/bin/git rev-parse --show-toplevel) && nix run git+https://gitlab.schukai.com/schukai/entwicklung/nix-flakes#git-commit --no-write-lock-file
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"

          gitleaks:
            desc: Run gitleaks to check for secrets in the repository.
            aliases:
              - gl
            cmds:
              - ${pkgs'.gitleaks}/bin/gitleaks git --verbose "{{.USER_WORKING_DIR}}"
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"

          update-project:
            desc: Check code style, linting, and formatting.
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            cmds:
              - ${scriptUpdateProject}/bin/update-project
            aliases:
              - u
            silent: true

          update-web-test:
            desc: Update the web test
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            cmds:
              - ${scriptUpdateWebTest}/bin/update-web-test
            aliases:
              - w
            silent: true

          init-project:
            desc: Initialize the project and install dependencies
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            cmds:
              - ${scriptInitProject}/bin/init-project
            aliases:
              - i
            silent: true

          build-stylesheets:
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            desc: Build the stylesheets javascript files
            cmds:
              - ${scriptBuildStylesheets}/bin/build-stylesheets
            aliases:
              - s

          run-tests:
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            desc: Run tests with node
            cmds:
              - ${scriptRunTests}/bin/run-tests
            aliases:
              - t

          run-web-tests:
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            desc: Run the tests in the browser
            cmds:
              - ${scriptUpdateWebTest}/bin/update-web-test
              - ${scriptRunWebTests}/bin/run-web-tests
            aliases:
              - b

          create-new-class:
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            desc: Create a new component class
            cmds:
              - ${scriptCreateNewComponentclass}/bin/create-new-class
            aliases:
              - c

          create-documentation-files:
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            desc: Create the documentation files
            cmds:
              - ${scriptCreateDocumentationFiles}/bin/create-documentation-files
            aliases:
              - d

          create-issue:
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            desc: Create a new issue
            cmds:
              - ${scriptCreateIssue}/bin/create-issue
            aliases:
              - e

          deploy:
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            desc: Build and publish the npm package
            cmds:
              - ${scriptDeploy}/bin/deploy
            aliases:
              - p

          update-changelog:
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            desc: Update the changelog
            cmds:
              - ${scriptUpdateChangelog}/bin/update-changelog
            aliases:
              - l

          start-server:
            desc: Start the server
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"
            cmds:
              - ${scriptStartServer}/bin/start-server
            silent: true
            aliases:
              - r
              - start

          tool-mockoon:
            desc: Run example
            aliases:
              - m
              - mockoon
            cmds:
              - ${pkgs'.mockoon}/bin/mockoon
            silent: true
            env:
              USER_WORKING_DIR: "{{.USER_WORKING_DIR}}"


    '';
  };
in
  pkgs'.writeShellScriptBin "task" ''
    ${pkgs'.go-task}/bin/task -t "${taskfile}" "$@"
  ''
